@@ -11,6 +11,7 @@ __author__ = 'Martin Pitt'
 __copyright__ = '(c) 2012 Canonical Ltd.'
 
 import copy
+import functools
 import importlib
 import importlib.util
 import os
@@ -120,12 +121,31 @@ def _wrap_in_dbus_variant(value):
     raise dbus.exceptions.DBusException(f'could not wrap type {type(value)}')
 
 
+def loggedmethod(self, func):
+    """Decorator for a method to end in the call log"""
+
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        fname = func.__name__
+        log_args = args[1:]  # args[0] is self
+        self.log(fname + _format_args(log_args))
+        self.call_log.append((int(time.time()), fname, log_args))
+        self.MethodCalled(fname, log_args)
+
+        return func(*args, **kwargs)
+
+    return wrapper
+
+
 class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-attributes
     '''Mock D-Bus object
 
     This can be configured to have arbitrary methods (including code execution)
     and properties via methods on the org.freedesktop.DBus.Mock interface, so
     that you can control the mock from any programming language.
+
+    Beyond that "remote control" API, this is a standard dbus-python service object, see
+    <https://dbus.freedesktop.org/doc/dbus-python/tutorial.html#exporting-objects>.
     '''
 
     def __init__(self, bus_name: str, path: str, interface: str, props: PropsType,
@@ -202,7 +222,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
     def Get(self, interface_name: str, property_name: str) -> Any:
         '''Standard D-Bus API for getting a property value'''
 
-        self.log(f'Get {interface_name}.{property_name}')
+        self.log(f'Get {self.path} {interface_name}.{property_name}')
 
         if not interface_name:
             interface_name = self.interface
@@ -218,7 +238,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
     def GetAll(self, interface_name: str, *_, **__) -> PropsType:
         '''Standard D-Bus API for getting all property values'''
 
-        self.log('GetAll ' + interface_name)
+        self.log(f'GetAll {self.path} {interface_name}')
 
         if not interface_name:
             interface_name = self.interface
@@ -234,7 +254,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
     def Set(self, interface_name: str, property_name: str, value: Any, *_, **__) -> None:
         '''Standard D-Bus API for setting a property value'''
 
-        self.log(f'Set {interface_name}.{property_name}{_format_args((value,))}')
+        self.log(f'Set {self.path} {interface_name}.{property_name}{_format_args((value,))}')
 
         try:
             iface_props = self.props[interface_name]
@@ -262,7 +282,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
                          in_signature='ssa{sv}a(ssss)',
                          out_signature='')
     def AddObject(self, path: str, interface: str, properties: PropsType, methods: List[MethodType]) -> None:
-        '''Add a new D-Bus object to the mock
+        '''Dynamically add a new D-Bus object to the mock
 
         path: D-Bus object path
         interface: Primary D-Bus interface name of this object (where
@@ -359,7 +379,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
                          in_signature='sssss',
                          out_signature='')
     def AddMethod(self, interface, name: str, in_sig: str, out_sig: str, code: str) -> None:
-        '''Add a method to this object
+        '''Dynamically add a method to this object
 
         interface: D-Bus interface to add this to. For convenience you can
                    specify '' here to add the method to the object's main
@@ -383,8 +403,20 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
               "self.my_state = True", and another method that returns it with
               "ret = self.my_state".
 
+              Methods can raise exceptions in the usual way, in particular
+              dbus.exceptions.DBusException:
+              <https://dbus.freedesktop.org/doc/dbus-python/dbus.html#dbus.DBusException>
+
               When specifying '', the method will not do anything (except
               logging) and return None.
+
+
+        This is meant for adding a method to a mock at runtime, from any programming language.
+        You can also use it in templates in the load() function.
+
+        For implementing non-trivial and static methods in templates, it is recommended to
+        implement them in the normal dbus-python way with using the @dbus.service.method
+        decorator instead.
         '''
         # pylint: disable=protected-access
 
@@ -533,6 +565,8 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
             # pylint: disable=protected-access
             fn = getattr(module, symbol)
             if ('_dbus_interface' in dir(fn) and ('_dbus_is_signal' not in dir(fn) or not fn._dbus_is_signal)):
+                fn = loggedmethod(self, fn)
+
                 # for dbus-python compatibility, add methods as callables
                 setattr(self.__class__, symbol, fn)
                 self.methods.setdefault(fn._dbus_interface, {})[str(symbol)] = (
@@ -578,7 +612,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
         m.append(signature=signature, *args)
         args = m.get_args_list()
 
-        fn = lambda self, *args: self.log(f'emit {interface}.{name}{_format_args(args)}')
+        fn = lambda self, *args: self.log(f'emit {self.path} {interface}.{name}{_format_args(args)}')
         fn.__name__ = str(name)
         dbus_fn = dbus.service.signal(interface)(fn)
         dbus_fn._dbus_signature = signature
